#ifndef status_h
#define status_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_status: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_status */
public:
	MODULE_status (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc, char *argv[], bool);
	int message (const char *msg,
		 int argc,
		 const char *argv[]);
	void setmenu (DIALOG&dia, MENU_CONTEXT context);
    /*~PROTOEND~ MODULE_status */
};

#include "status.p"

#endif
